# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class MediaStream(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'codec': 'str',
        'codec_tag': 'str',
        'language': 'str',
        'color_transfer': 'str',
        'color_primaries': 'str',
        'color_space': 'str',
        'comment': 'str',
        'stream_start_time_ticks': 'int',
        'time_base': 'str',
        'title': 'str',
        'extradata': 'str',
        'video_range': 'str',
        'display_title': 'str',
        'display_language': 'str',
        'nal_length_size': 'str',
        'is_interlaced': 'bool',
        'is_avc': 'bool',
        'channel_layout': 'str',
        'bit_rate': 'int',
        'bit_depth': 'int',
        'ref_frames': 'int',
        'rotation': 'int',
        'channels': 'int',
        'sample_rate': 'int',
        'is_default': 'bool',
        'is_forced': 'bool',
        'is_hearing_impaired': 'bool',
        'height': 'int',
        'width': 'int',
        'average_frame_rate': 'float',
        'real_frame_rate': 'float',
        'profile': 'str',
        'type': 'MediaStreamType',
        'aspect_ratio': 'str',
        'index': 'int',
        'is_external': 'bool',
        'delivery_method': 'SubtitleDeliveryMethod',
        'delivery_url': 'str',
        'is_external_url': 'bool',
        'is_text_subtitle_stream': 'bool',
        'supports_external_stream': 'bool',
        'path': 'str',
        'protocol': 'MediaProtocol',
        'pixel_format': 'str',
        'level': 'float',
        'is_anamorphic': 'bool',
        'extended_video_type': 'ExtendedVideoTypes',
        'extended_video_sub_type': 'ExtendedVideoSubTypes',
        'extended_video_sub_type_description': 'str',
        'item_id': 'str',
        'server_id': 'str',
        'attachment_size': 'int',
        'mime_type': 'str',
        'subtitle_location_type': 'SubtitleLocationType'
    }

    attribute_map = {
        'codec': 'Codec',
        'codec_tag': 'CodecTag',
        'language': 'Language',
        'color_transfer': 'ColorTransfer',
        'color_primaries': 'ColorPrimaries',
        'color_space': 'ColorSpace',
        'comment': 'Comment',
        'stream_start_time_ticks': 'StreamStartTimeTicks',
        'time_base': 'TimeBase',
        'title': 'Title',
        'extradata': 'Extradata',
        'video_range': 'VideoRange',
        'display_title': 'DisplayTitle',
        'display_language': 'DisplayLanguage',
        'nal_length_size': 'NalLengthSize',
        'is_interlaced': 'IsInterlaced',
        'is_avc': 'IsAVC',
        'channel_layout': 'ChannelLayout',
        'bit_rate': 'BitRate',
        'bit_depth': 'BitDepth',
        'ref_frames': 'RefFrames',
        'rotation': 'Rotation',
        'channels': 'Channels',
        'sample_rate': 'SampleRate',
        'is_default': 'IsDefault',
        'is_forced': 'IsForced',
        'is_hearing_impaired': 'IsHearingImpaired',
        'height': 'Height',
        'width': 'Width',
        'average_frame_rate': 'AverageFrameRate',
        'real_frame_rate': 'RealFrameRate',
        'profile': 'Profile',
        'type': 'Type',
        'aspect_ratio': 'AspectRatio',
        'index': 'Index',
        'is_external': 'IsExternal',
        'delivery_method': 'DeliveryMethod',
        'delivery_url': 'DeliveryUrl',
        'is_external_url': 'IsExternalUrl',
        'is_text_subtitle_stream': 'IsTextSubtitleStream',
        'supports_external_stream': 'SupportsExternalStream',
        'path': 'Path',
        'protocol': 'Protocol',
        'pixel_format': 'PixelFormat',
        'level': 'Level',
        'is_anamorphic': 'IsAnamorphic',
        'extended_video_type': 'ExtendedVideoType',
        'extended_video_sub_type': 'ExtendedVideoSubType',
        'extended_video_sub_type_description': 'ExtendedVideoSubTypeDescription',
        'item_id': 'ItemId',
        'server_id': 'ServerId',
        'attachment_size': 'AttachmentSize',
        'mime_type': 'MimeType',
        'subtitle_location_type': 'SubtitleLocationType'
    }

    def __init__(self, codec=None, codec_tag=None, language=None, color_transfer=None, color_primaries=None, color_space=None, comment=None, stream_start_time_ticks=None, time_base=None, title=None, extradata=None, video_range=None, display_title=None, display_language=None, nal_length_size=None, is_interlaced=None, is_avc=None, channel_layout=None, bit_rate=None, bit_depth=None, ref_frames=None, rotation=None, channels=None, sample_rate=None, is_default=None, is_forced=None, is_hearing_impaired=None, height=None, width=None, average_frame_rate=None, real_frame_rate=None, profile=None, type=None, aspect_ratio=None, index=None, is_external=None, delivery_method=None, delivery_url=None, is_external_url=None, is_text_subtitle_stream=None, supports_external_stream=None, path=None, protocol=None, pixel_format=None, level=None, is_anamorphic=None, extended_video_type=None, extended_video_sub_type=None, extended_video_sub_type_description=None, item_id=None, server_id=None, attachment_size=None, mime_type=None, subtitle_location_type=None):  # noqa: E501
        """MediaStream - a model defined in Swagger"""  # noqa: E501
        self._codec = None
        self._codec_tag = None
        self._language = None
        self._color_transfer = None
        self._color_primaries = None
        self._color_space = None
        self._comment = None
        self._stream_start_time_ticks = None
        self._time_base = None
        self._title = None
        self._extradata = None
        self._video_range = None
        self._display_title = None
        self._display_language = None
        self._nal_length_size = None
        self._is_interlaced = None
        self._is_avc = None
        self._channel_layout = None
        self._bit_rate = None
        self._bit_depth = None
        self._ref_frames = None
        self._rotation = None
        self._channels = None
        self._sample_rate = None
        self._is_default = None
        self._is_forced = None
        self._is_hearing_impaired = None
        self._height = None
        self._width = None
        self._average_frame_rate = None
        self._real_frame_rate = None
        self._profile = None
        self._type = None
        self._aspect_ratio = None
        self._index = None
        self._is_external = None
        self._delivery_method = None
        self._delivery_url = None
        self._is_external_url = None
        self._is_text_subtitle_stream = None
        self._supports_external_stream = None
        self._path = None
        self._protocol = None
        self._pixel_format = None
        self._level = None
        self._is_anamorphic = None
        self._extended_video_type = None
        self._extended_video_sub_type = None
        self._extended_video_sub_type_description = None
        self._item_id = None
        self._server_id = None
        self._attachment_size = None
        self._mime_type = None
        self._subtitle_location_type = None
        self.discriminator = None
        if codec is not None:
            self.codec = codec
        if codec_tag is not None:
            self.codec_tag = codec_tag
        if language is not None:
            self.language = language
        if color_transfer is not None:
            self.color_transfer = color_transfer
        if color_primaries is not None:
            self.color_primaries = color_primaries
        if color_space is not None:
            self.color_space = color_space
        if comment is not None:
            self.comment = comment
        if stream_start_time_ticks is not None:
            self.stream_start_time_ticks = stream_start_time_ticks
        if time_base is not None:
            self.time_base = time_base
        if title is not None:
            self.title = title
        if extradata is not None:
            self.extradata = extradata
        if video_range is not None:
            self.video_range = video_range
        if display_title is not None:
            self.display_title = display_title
        if display_language is not None:
            self.display_language = display_language
        if nal_length_size is not None:
            self.nal_length_size = nal_length_size
        if is_interlaced is not None:
            self.is_interlaced = is_interlaced
        if is_avc is not None:
            self.is_avc = is_avc
        if channel_layout is not None:
            self.channel_layout = channel_layout
        if bit_rate is not None:
            self.bit_rate = bit_rate
        if bit_depth is not None:
            self.bit_depth = bit_depth
        if ref_frames is not None:
            self.ref_frames = ref_frames
        if rotation is not None:
            self.rotation = rotation
        if channels is not None:
            self.channels = channels
        if sample_rate is not None:
            self.sample_rate = sample_rate
        if is_default is not None:
            self.is_default = is_default
        if is_forced is not None:
            self.is_forced = is_forced
        if is_hearing_impaired is not None:
            self.is_hearing_impaired = is_hearing_impaired
        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if average_frame_rate is not None:
            self.average_frame_rate = average_frame_rate
        if real_frame_rate is not None:
            self.real_frame_rate = real_frame_rate
        if profile is not None:
            self.profile = profile
        if type is not None:
            self.type = type
        if aspect_ratio is not None:
            self.aspect_ratio = aspect_ratio
        if index is not None:
            self.index = index
        if is_external is not None:
            self.is_external = is_external
        if delivery_method is not None:
            self.delivery_method = delivery_method
        if delivery_url is not None:
            self.delivery_url = delivery_url
        if is_external_url is not None:
            self.is_external_url = is_external_url
        if is_text_subtitle_stream is not None:
            self.is_text_subtitle_stream = is_text_subtitle_stream
        if supports_external_stream is not None:
            self.supports_external_stream = supports_external_stream
        if path is not None:
            self.path = path
        if protocol is not None:
            self.protocol = protocol
        if pixel_format is not None:
            self.pixel_format = pixel_format
        if level is not None:
            self.level = level
        if is_anamorphic is not None:
            self.is_anamorphic = is_anamorphic
        if extended_video_type is not None:
            self.extended_video_type = extended_video_type
        if extended_video_sub_type is not None:
            self.extended_video_sub_type = extended_video_sub_type
        if extended_video_sub_type_description is not None:
            self.extended_video_sub_type_description = extended_video_sub_type_description
        if item_id is not None:
            self.item_id = item_id
        if server_id is not None:
            self.server_id = server_id
        if attachment_size is not None:
            self.attachment_size = attachment_size
        if mime_type is not None:
            self.mime_type = mime_type
        if subtitle_location_type is not None:
            self.subtitle_location_type = subtitle_location_type

    @property
    def codec(self):
        """Gets the codec of this MediaStream.  # noqa: E501

        The codec.    Probe Field: `codec_name`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`    Related Enums: `T:Emby.Media.Model.Enums.VideoMediaTypes`, `Emby.Media.Model.Enums.AudioMediaTypes`, `Emby.Media.Model.Enums.SubtitleMediaTypes`.  # noqa: E501

        :return: The codec of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        """Sets the codec of this MediaStream.

        The codec.    Probe Field: `codec_name`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`    Related Enums: `T:Emby.Media.Model.Enums.VideoMediaTypes`, `Emby.Media.Model.Enums.AudioMediaTypes`, `Emby.Media.Model.Enums.SubtitleMediaTypes`.  # noqa: E501

        :param codec: The codec of this MediaStream.  # noqa: E501
        :type: str
        """

        self._codec = codec

    @property
    def codec_tag(self):
        """Gets the codec_tag of this MediaStream.  # noqa: E501

        The codec tag.    Probe Field: `codec_tag`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :return: The codec_tag of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._codec_tag

    @codec_tag.setter
    def codec_tag(self, codec_tag):
        """Sets the codec_tag of this MediaStream.

        The codec tag.    Probe Field: `codec_tag`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :param codec_tag: The codec_tag of this MediaStream.  # noqa: E501
        :type: str
        """

        self._codec_tag = codec_tag

    @property
    def language(self):
        """Gets the language of this MediaStream.  # noqa: E501

        The language.    Probe Field: `tags[\"language\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :return: The language of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this MediaStream.

        The language.    Probe Field: `tags[\"language\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :param language: The language of this MediaStream.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def color_transfer(self):
        """Gets the color_transfer of this MediaStream.  # noqa: E501

        The color transfer characteristics.    Probe Field: `color_transfer`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`    Related Enum: `Emby.Media.Model.Enums.ColorTransfers`.  # noqa: E501

        :return: The color_transfer of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._color_transfer

    @color_transfer.setter
    def color_transfer(self, color_transfer):
        """Sets the color_transfer of this MediaStream.

        The color transfer characteristics.    Probe Field: `color_transfer`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`    Related Enum: `Emby.Media.Model.Enums.ColorTransfers`.  # noqa: E501

        :param color_transfer: The color_transfer of this MediaStream.  # noqa: E501
        :type: str
        """

        self._color_transfer = color_transfer

    @property
    def color_primaries(self):
        """Gets the color_primaries of this MediaStream.  # noqa: E501

        The chromaticity coordinates of the source primaries.    Probe Field: `color_primaries`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`    Related Enum: `Emby.Media.Model.Enums.ColorPrimaries`.  # noqa: E501

        :return: The color_primaries of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._color_primaries

    @color_primaries.setter
    def color_primaries(self, color_primaries):
        """Sets the color_primaries of this MediaStream.

        The chromaticity coordinates of the source primaries.    Probe Field: `color_primaries`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`    Related Enum: `Emby.Media.Model.Enums.ColorPrimaries`.  # noqa: E501

        :param color_primaries: The color_primaries of this MediaStream.  # noqa: E501
        :type: str
        """

        self._color_primaries = color_primaries

    @property
    def color_space(self):
        """Gets the color_space of this MediaStream.  # noqa: E501

        The YUV colorspace type.    Probe Field: `color_space`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`    Related Enum: `Emby.Media.Model.Enums.ColorSpaces`.  # noqa: E501

        :return: The color_space of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._color_space

    @color_space.setter
    def color_space(self, color_space):
        """Sets the color_space of this MediaStream.

        The YUV colorspace type.    Probe Field: `color_space`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`    Related Enum: `Emby.Media.Model.Enums.ColorSpaces`.  # noqa: E501

        :param color_space: The color_space of this MediaStream.  # noqa: E501
        :type: str
        """

        self._color_space = color_space

    @property
    def comment(self):
        """Gets the comment of this MediaStream.  # noqa: E501

        The comment.    Probe Field: `tags[\"comment\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :return: The comment of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this MediaStream.

        The comment.    Probe Field: `tags[\"comment\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :param comment: The comment of this MediaStream.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def stream_start_time_ticks(self):
        """Gets the stream_start_time_ticks of this MediaStream.  # noqa: E501

        The start time of the stream.    Probe Field: `start_time`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.    Actual type: `System.TimeSpan`.  # noqa: E501

        :return: The stream_start_time_ticks of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._stream_start_time_ticks

    @stream_start_time_ticks.setter
    def stream_start_time_ticks(self, stream_start_time_ticks):
        """Sets the stream_start_time_ticks of this MediaStream.

        The start time of the stream.    Probe Field: `start_time`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.    Actual type: `System.TimeSpan`.  # noqa: E501

        :param stream_start_time_ticks: The stream_start_time_ticks of this MediaStream.  # noqa: E501
        :type: int
        """

        self._stream_start_time_ticks = stream_start_time_ticks

    @property
    def time_base(self):
        """Gets the time_base of this MediaStream.  # noqa: E501

        The time\\-base.    Probe Field: `time_base`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.    Actual type: `Emby.Media.Model.Types.Rational`.  # noqa: E501

        :return: The time_base of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._time_base

    @time_base.setter
    def time_base(self, time_base):
        """Sets the time_base of this MediaStream.

        The time\\-base.    Probe Field: `time_base`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.    Actual type: `Emby.Media.Model.Types.Rational`.  # noqa: E501

        :param time_base: The time_base of this MediaStream.  # noqa: E501
        :type: str
        """

        self._time_base = time_base

    @property
    def title(self):
        """Gets the title of this MediaStream.  # noqa: E501

        The title.    Probe Field: `tags[\"title\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :return: The title of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this MediaStream.

        The title.    Probe Field: `tags[\"title\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :param title: The title of this MediaStream.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def extradata(self):
        """Gets the extradata of this MediaStream.  # noqa: E501

        The extradata.    Probe Field: `extradata`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.    Currently, this value is only parsed for subtitle streams with codec `Emby.Media.Model.Enums.SubtitleMediaTypes.dvb_teletext`.  # noqa: E501

        :return: The extradata of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._extradata

    @extradata.setter
    def extradata(self, extradata):
        """Sets the extradata of this MediaStream.

        The extradata.    Probe Field: `extradata`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.    Currently, this value is only parsed for subtitle streams with codec `Emby.Media.Model.Enums.SubtitleMediaTypes.dvb_teletext`.  # noqa: E501

        :param extradata: The extradata of this MediaStream.  # noqa: E501
        :type: str
        """

        self._extradata = extradata

    @property
    def video_range(self):
        """Gets the video_range of this MediaStream.  # noqa: E501


        :return: The video_range of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._video_range

    @video_range.setter
    def video_range(self, video_range):
        """Sets the video_range of this MediaStream.


        :param video_range: The video_range of this MediaStream.  # noqa: E501
        :type: str
        """

        self._video_range = video_range

    @property
    def display_title(self):
        """Gets the display_title of this MediaStream.  # noqa: E501

        The display title.    Custom property set by the application.  # noqa: E501

        :return: The display_title of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._display_title

    @display_title.setter
    def display_title(self, display_title):
        """Sets the display_title of this MediaStream.

        The display title.    Custom property set by the application.  # noqa: E501

        :param display_title: The display_title of this MediaStream.  # noqa: E501
        :type: str
        """

        self._display_title = display_title

    @property
    def display_language(self):
        """Gets the display_language of this MediaStream.  # noqa: E501

        The display language.    Custom property set by the application.  # noqa: E501

        :return: The display_language of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._display_language

    @display_language.setter
    def display_language(self, display_language):
        """Sets the display_language of this MediaStream.

        The display language.    Custom property set by the application.  # noqa: E501

        :param display_language: The display_language of this MediaStream.  # noqa: E501
        :type: str
        """

        self._display_language = display_language

    @property
    def nal_length_size(self):
        """Gets the nal_length_size of this MediaStream.  # noqa: E501

        The nal length size.    Probe Field: `nal_length_size`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video` of type `Emby.Media.Model.Enums.VideoMediaTypes.h264`.    Actual type: `System.Int32`.  # noqa: E501

        :return: The nal_length_size of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._nal_length_size

    @nal_length_size.setter
    def nal_length_size(self, nal_length_size):
        """Sets the nal_length_size of this MediaStream.

        The nal length size.    Probe Field: `nal_length_size`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video` of type `Emby.Media.Model.Enums.VideoMediaTypes.h264`.    Actual type: `System.Int32`.  # noqa: E501

        :param nal_length_size: The nal_length_size of this MediaStream.  # noqa: E501
        :type: str
        """

        self._nal_length_size = nal_length_size

    @property
    def is_interlaced(self):
        """Gets the is_interlaced of this MediaStream.  # noqa: E501

        A value indicating whether this instance is interlaced.    Probe Field: `field_order` \\!\\= `progressive`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.  # noqa: E501

        :return: The is_interlaced of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_interlaced

    @is_interlaced.setter
    def is_interlaced(self, is_interlaced):
        """Sets the is_interlaced of this MediaStream.

        A value indicating whether this instance is interlaced.    Probe Field: `field_order` \\!\\= `progressive`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.  # noqa: E501

        :param is_interlaced: The is_interlaced of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_interlaced = is_interlaced

    @property
    def is_avc(self):
        """Gets the is_avc of this MediaStream.  # noqa: E501


        :return: The is_avc of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_avc

    @is_avc.setter
    def is_avc(self, is_avc):
        """Sets the is_avc of this MediaStream.


        :param is_avc: The is_avc of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_avc = is_avc

    @property
    def channel_layout(self):
        """Gets the channel_layout of this MediaStream.  # noqa: E501

        The channel layout.    Probe Field: `channel_layout`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Audio`    Related Enum: `MediaBrowser.Model.Entities.MediaStream.ChannelLayout`.  # noqa: E501

        :return: The channel_layout of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._channel_layout

    @channel_layout.setter
    def channel_layout(self, channel_layout):
        """Sets the channel_layout of this MediaStream.

        The channel layout.    Probe Field: `channel_layout`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Audio`    Related Enum: `MediaBrowser.Model.Entities.MediaStream.ChannelLayout`.  # noqa: E501

        :param channel_layout: The channel_layout of this MediaStream.  # noqa: E501
        :type: str
        """

        self._channel_layout = channel_layout

    @property
    def bit_rate(self):
        """Gets the bit_rate of this MediaStream.  # noqa: E501

        The bit rate.    Probe Field: `bit_rate`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`.    THIS VALUE IS PROCESSED BY CUSTOM LOGIC AND DOES NOT NECESSARILY MATCH FFPROBE RESULTS\\!  # noqa: E501

        :return: The bit_rate of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._bit_rate

    @bit_rate.setter
    def bit_rate(self, bit_rate):
        """Sets the bit_rate of this MediaStream.

        The bit rate.    Probe Field: `bit_rate`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`.    THIS VALUE IS PROCESSED BY CUSTOM LOGIC AND DOES NOT NECESSARILY MATCH FFPROBE RESULTS\\!  # noqa: E501

        :param bit_rate: The bit_rate of this MediaStream.  # noqa: E501
        :type: int
        """

        self._bit_rate = bit_rate

    @property
    def bit_depth(self):
        """Gets the bit_depth of this MediaStream.  # noqa: E501

        The bit depth.    Probe Field: `bits_per_sample` or `bits_per_raw_sample`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`.  # noqa: E501

        :return: The bit_depth of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._bit_depth

    @bit_depth.setter
    def bit_depth(self, bit_depth):
        """Sets the bit_depth of this MediaStream.

        The bit depth.    Probe Field: `bits_per_sample` or `bits_per_raw_sample`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`.  # noqa: E501

        :param bit_depth: The bit_depth of this MediaStream.  # noqa: E501
        :type: int
        """

        self._bit_depth = bit_depth

    @property
    def ref_frames(self):
        """Gets the ref_frames of this MediaStream.  # noqa: E501

        The reference frames.    Probe Field: `refs`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.  # noqa: E501

        :return: The ref_frames of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._ref_frames

    @ref_frames.setter
    def ref_frames(self, ref_frames):
        """Sets the ref_frames of this MediaStream.

        The reference frames.    Probe Field: `refs`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.  # noqa: E501

        :param ref_frames: The ref_frames of this MediaStream.  # noqa: E501
        :type: int
        """

        self._ref_frames = ref_frames

    @property
    def rotation(self):
        """Gets the rotation of this MediaStream.  # noqa: E501


        :return: The rotation of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._rotation

    @rotation.setter
    def rotation(self, rotation):
        """Sets the rotation of this MediaStream.


        :param rotation: The rotation of this MediaStream.  # noqa: E501
        :type: int
        """

        self._rotation = rotation

    @property
    def channels(self):
        """Gets the channels of this MediaStream.  # noqa: E501

        The audio channel count.    Probe Field: `channels`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Audio`.  # noqa: E501

        :return: The channels of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._channels

    @channels.setter
    def channels(self, channels):
        """Sets the channels of this MediaStream.

        The audio channel count.    Probe Field: `channels`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Audio`.  # noqa: E501

        :param channels: The channels of this MediaStream.  # noqa: E501
        :type: int
        """

        self._channels = channels

    @property
    def sample_rate(self):
        """Gets the sample_rate of this MediaStream.  # noqa: E501

        The sample rate.    Probe Field: `sample_rate`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Audio`    Related Enum: `Emby.Media.Model.Enums.SampleRates`.  # noqa: E501

        :return: The sample_rate of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._sample_rate

    @sample_rate.setter
    def sample_rate(self, sample_rate):
        """Sets the sample_rate of this MediaStream.

        The sample rate.    Probe Field: `sample_rate`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Audio`    Related Enum: `Emby.Media.Model.Enums.SampleRates`.  # noqa: E501

        :param sample_rate: The sample_rate of this MediaStream.  # noqa: E501
        :type: int
        """

        self._sample_rate = sample_rate

    @property
    def is_default(self):
        """Gets the is_default of this MediaStream.  # noqa: E501

        A value indicating whether this instance is default.    Probe Field: `disposition[\"default\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :return: The is_default of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this MediaStream.

        A value indicating whether this instance is default.    Probe Field: `disposition[\"default\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :param is_default: The is_default of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def is_forced(self):
        """Gets the is_forced of this MediaStream.  # noqa: E501

        A value indicating whether this instance is forced.    Probe Field: `disposition[\"forced\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :return: The is_forced of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_forced

    @is_forced.setter
    def is_forced(self, is_forced):
        """Sets the is_forced of this MediaStream.

        A value indicating whether this instance is forced.    Probe Field: `disposition[\"forced\"]`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :param is_forced: The is_forced of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_forced = is_forced

    @property
    def is_hearing_impaired(self):
        """Gets the is_hearing_impaired of this MediaStream.  # noqa: E501


        :return: The is_hearing_impaired of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_hearing_impaired

    @is_hearing_impaired.setter
    def is_hearing_impaired(self, is_hearing_impaired):
        """Sets the is_hearing_impaired of this MediaStream.


        :param is_hearing_impaired: The is_hearing_impaired of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_hearing_impaired = is_hearing_impaired

    @property
    def height(self):
        """Gets the height of this MediaStream.  # noqa: E501

        The height.    Probe Field: `height`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.  # noqa: E501

        :return: The height of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this MediaStream.

        The height.    Probe Field: `height`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.  # noqa: E501

        :param height: The height of this MediaStream.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def width(self):
        """Gets the width of this MediaStream.  # noqa: E501

        The width.    Probe Field: `width`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.  # noqa: E501

        :return: The width of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this MediaStream.

        The width.    Probe Field: `width`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.  # noqa: E501

        :param width: The width of this MediaStream.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def average_frame_rate(self):
        """Gets the average_frame_rate of this MediaStream.  # noqa: E501

        The average frame rate..    Probe Field: `avg_frame_rate`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.    Actual type: `Emby.Media.Model.Types.Rational`.  # noqa: E501

        :return: The average_frame_rate of this MediaStream.  # noqa: E501
        :rtype: float
        """
        return self._average_frame_rate

    @average_frame_rate.setter
    def average_frame_rate(self, average_frame_rate):
        """Sets the average_frame_rate of this MediaStream.

        The average frame rate..    Probe Field: `avg_frame_rate`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.    Actual type: `Emby.Media.Model.Types.Rational`.  # noqa: E501

        :param average_frame_rate: The average_frame_rate of this MediaStream.  # noqa: E501
        :type: float
        """

        self._average_frame_rate = average_frame_rate

    @property
    def real_frame_rate(self):
        """Gets the real_frame_rate of this MediaStream.  # noqa: E501

        The real frame rate..    Probe Field: `r_frame_rate`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.    Actual type: `Emby.Media.Model.Types.Rational`.  # noqa: E501

        :return: The real_frame_rate of this MediaStream.  # noqa: E501
        :rtype: float
        """
        return self._real_frame_rate

    @real_frame_rate.setter
    def real_frame_rate(self, real_frame_rate):
        """Sets the real_frame_rate of this MediaStream.

        The real frame rate..    Probe Field: `r_frame_rate`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.    Actual type: `Emby.Media.Model.Types.Rational`.  # noqa: E501

        :param real_frame_rate: The real_frame_rate of this MediaStream.  # noqa: E501
        :type: float
        """

        self._real_frame_rate = real_frame_rate

    @property
    def profile(self):
        """Gets the profile of this MediaStream.  # noqa: E501

        The profile.    Probe Field: `profile`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`    Related Enums: `Emby.Media.Model.Enums.AacProfiles`, `Emby.Media.Model.Enums.AvcProfiles`, `Emby.Media.Model.Enums.H263Profiles`, `Emby.Media.Model.Enums.HevcProfiles`, `Emby.Media.Model.Enums.Mpeg2Profiles`,`Emby.Media.Model.Enums.Vc1Profiles`, `Emby.Media.Model.Enums.Mpeg4Profiles`, `Emby.Media.Model.Enums.Vp8Profiles`, `Emby.Media.Model.Enums.Vp9Profiles`.  # noqa: E501

        :return: The profile of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this MediaStream.

        The profile.    Probe Field: `profile`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`    Related Enums: `Emby.Media.Model.Enums.AacProfiles`, `Emby.Media.Model.Enums.AvcProfiles`, `Emby.Media.Model.Enums.H263Profiles`, `Emby.Media.Model.Enums.HevcProfiles`, `Emby.Media.Model.Enums.Mpeg2Profiles`,`Emby.Media.Model.Enums.Vc1Profiles`, `Emby.Media.Model.Enums.Mpeg4Profiles`, `Emby.Media.Model.Enums.Vp8Profiles`, `Emby.Media.Model.Enums.Vp9Profiles`.  # noqa: E501

        :param profile: The profile of this MediaStream.  # noqa: E501
        :type: str
        """

        self._profile = profile

    @property
    def type(self):
        """Gets the type of this MediaStream.  # noqa: E501


        :return: The type of this MediaStream.  # noqa: E501
        :rtype: MediaStreamType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MediaStream.


        :param type: The type of this MediaStream.  # noqa: E501
        :type: MediaStreamType
        """

        self._type = type

    @property
    def aspect_ratio(self):
        """Gets the aspect_ratio of this MediaStream.  # noqa: E501

        The aspect ratio.    Probe Field: `display_aspect_ratio`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.    Actual type: `Emby.Media.Model.Types.Rational`.  # noqa: E501

        :return: The aspect_ratio of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._aspect_ratio

    @aspect_ratio.setter
    def aspect_ratio(self, aspect_ratio):
        """Sets the aspect_ratio of this MediaStream.

        The aspect ratio.    Probe Field: `display_aspect_ratio`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.    Actual type: `Emby.Media.Model.Types.Rational`.  # noqa: E501

        :param aspect_ratio: The aspect_ratio of this MediaStream.  # noqa: E501
        :type: str
        """

        self._aspect_ratio = aspect_ratio

    @property
    def index(self):
        """Gets the index of this MediaStream.  # noqa: E501

        The index of the stream inside its container.    Probe Field: `index`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :return: The index of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this MediaStream.

        The index of the stream inside its container.    Probe Field: `index`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`, `MediaBrowser.Model.Entities.MediaStreamType.Audio`, `MediaBrowser.Model.Entities.MediaStreamType.Subtitle`.  # noqa: E501

        :param index: The index of this MediaStream.  # noqa: E501
        :type: int
        """

        self._index = index

    @property
    def is_external(self):
        """Gets the is_external of this MediaStream.  # noqa: E501

        A value indicating whether this instance is external.    Custom property set by the application.  # noqa: E501

        :return: The is_external of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_external

    @is_external.setter
    def is_external(self, is_external):
        """Sets the is_external of this MediaStream.

        A value indicating whether this instance is external.    Custom property set by the application.  # noqa: E501

        :param is_external: The is_external of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_external = is_external

    @property
    def delivery_method(self):
        """Gets the delivery_method of this MediaStream.  # noqa: E501


        :return: The delivery_method of this MediaStream.  # noqa: E501
        :rtype: SubtitleDeliveryMethod
        """
        return self._delivery_method

    @delivery_method.setter
    def delivery_method(self, delivery_method):
        """Sets the delivery_method of this MediaStream.


        :param delivery_method: The delivery_method of this MediaStream.  # noqa: E501
        :type: SubtitleDeliveryMethod
        """

        self._delivery_method = delivery_method

    @property
    def delivery_url(self):
        """Gets the delivery_url of this MediaStream.  # noqa: E501

        The delivery URL.    Custom property set by the application.  # noqa: E501

        :return: The delivery_url of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._delivery_url

    @delivery_url.setter
    def delivery_url(self, delivery_url):
        """Sets the delivery_url of this MediaStream.

        The delivery URL.    Custom property set by the application.  # noqa: E501

        :param delivery_url: The delivery_url of this MediaStream.  # noqa: E501
        :type: str
        """

        self._delivery_url = delivery_url

    @property
    def is_external_url(self):
        """Gets the is_external_url of this MediaStream.  # noqa: E501

        A value indicating whether this instance is external URL.    Custom property set by the application.  # noqa: E501

        :return: The is_external_url of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_external_url

    @is_external_url.setter
    def is_external_url(self, is_external_url):
        """Sets the is_external_url of this MediaStream.

        A value indicating whether this instance is external URL.    Custom property set by the application.  # noqa: E501

        :param is_external_url: The is_external_url of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_external_url = is_external_url

    @property
    def is_text_subtitle_stream(self):
        """Gets the is_text_subtitle_stream of this MediaStream.  # noqa: E501


        :return: The is_text_subtitle_stream of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_text_subtitle_stream

    @is_text_subtitle_stream.setter
    def is_text_subtitle_stream(self, is_text_subtitle_stream):
        """Sets the is_text_subtitle_stream of this MediaStream.


        :param is_text_subtitle_stream: The is_text_subtitle_stream of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_text_subtitle_stream = is_text_subtitle_stream

    @property
    def supports_external_stream(self):
        """Gets the supports_external_stream of this MediaStream.  # noqa: E501

        A value indicating whether \\[supports external stream\\].  # noqa: E501

        :return: The supports_external_stream of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._supports_external_stream

    @supports_external_stream.setter
    def supports_external_stream(self, supports_external_stream):
        """Sets the supports_external_stream of this MediaStream.

        A value indicating whether \\[supports external stream\\].  # noqa: E501

        :param supports_external_stream: The supports_external_stream of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._supports_external_stream = supports_external_stream

    @property
    def path(self):
        """Gets the path of this MediaStream.  # noqa: E501

        The filename.  # noqa: E501

        :return: The path of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this MediaStream.

        The filename.  # noqa: E501

        :param path: The path of this MediaStream.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def protocol(self):
        """Gets the protocol of this MediaStream.  # noqa: E501


        :return: The protocol of this MediaStream.  # noqa: E501
        :rtype: MediaProtocol
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this MediaStream.


        :param protocol: The protocol of this MediaStream.  # noqa: E501
        :type: MediaProtocol
        """

        self._protocol = protocol

    @property
    def pixel_format(self):
        """Gets the pixel_format of this MediaStream.  # noqa: E501

        The pixel format.    Probe Field: `pix_fmt`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.    Actual type: `MediaBrowser.Model.Entities.MediaStream.PixelFormat`.  # noqa: E501

        :return: The pixel_format of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._pixel_format

    @pixel_format.setter
    def pixel_format(self, pixel_format):
        """Sets the pixel_format of this MediaStream.

        The pixel format.    Probe Field: `pix_fmt`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`.    Actual type: `MediaBrowser.Model.Entities.MediaStream.PixelFormat`.  # noqa: E501

        :param pixel_format: The pixel_format of this MediaStream.  # noqa: E501
        :type: str
        """

        self._pixel_format = pixel_format

    @property
    def level(self):
        """Gets the level of this MediaStream.  # noqa: E501

        The codec level.    Probe Field: `level`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`    Related Enums: `Emby.Media.Model.Enums.AvcLevels`, `Emby.Media.Model.Enums.H263Levels`, `Emby.Media.Model.Enums.HevcLevels`, `Emby.Media.Model.Enums.Mpeg2Levels`,`Emby.Media.Model.Enums.Vc1Levels`, `Emby.Media.Model.Enums.Mpeg4Levels`, `Emby.Media.Model.Enums.Vp8Levels`, `Emby.Media.Model.Enums.Vp9Levels`.  # noqa: E501

        :return: The level of this MediaStream.  # noqa: E501
        :rtype: float
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this MediaStream.

        The codec level.    Probe Field: `level`    Applies to: `MediaBrowser.Model.Entities.MediaStreamType.Video`    Related Enums: `Emby.Media.Model.Enums.AvcLevels`, `Emby.Media.Model.Enums.H263Levels`, `Emby.Media.Model.Enums.HevcLevels`, `Emby.Media.Model.Enums.Mpeg2Levels`,`Emby.Media.Model.Enums.Vc1Levels`, `Emby.Media.Model.Enums.Mpeg4Levels`, `Emby.Media.Model.Enums.Vp8Levels`, `Emby.Media.Model.Enums.Vp9Levels`.  # noqa: E501

        :param level: The level of this MediaStream.  # noqa: E501
        :type: float
        """

        self._level = level

    @property
    def is_anamorphic(self):
        """Gets the is_anamorphic of this MediaStream.  # noqa: E501

        A value indicating whether this instance is anamorphic.  # noqa: E501

        :return: The is_anamorphic of this MediaStream.  # noqa: E501
        :rtype: bool
        """
        return self._is_anamorphic

    @is_anamorphic.setter
    def is_anamorphic(self, is_anamorphic):
        """Sets the is_anamorphic of this MediaStream.

        A value indicating whether this instance is anamorphic.  # noqa: E501

        :param is_anamorphic: The is_anamorphic of this MediaStream.  # noqa: E501
        :type: bool
        """

        self._is_anamorphic = is_anamorphic

    @property
    def extended_video_type(self):
        """Gets the extended_video_type of this MediaStream.  # noqa: E501


        :return: The extended_video_type of this MediaStream.  # noqa: E501
        :rtype: ExtendedVideoTypes
        """
        return self._extended_video_type

    @extended_video_type.setter
    def extended_video_type(self, extended_video_type):
        """Sets the extended_video_type of this MediaStream.


        :param extended_video_type: The extended_video_type of this MediaStream.  # noqa: E501
        :type: ExtendedVideoTypes
        """

        self._extended_video_type = extended_video_type

    @property
    def extended_video_sub_type(self):
        """Gets the extended_video_sub_type of this MediaStream.  # noqa: E501


        :return: The extended_video_sub_type of this MediaStream.  # noqa: E501
        :rtype: ExtendedVideoSubTypes
        """
        return self._extended_video_sub_type

    @extended_video_sub_type.setter
    def extended_video_sub_type(self, extended_video_sub_type):
        """Sets the extended_video_sub_type of this MediaStream.


        :param extended_video_sub_type: The extended_video_sub_type of this MediaStream.  # noqa: E501
        :type: ExtendedVideoSubTypes
        """

        self._extended_video_sub_type = extended_video_sub_type

    @property
    def extended_video_sub_type_description(self):
        """Gets the extended_video_sub_type_description of this MediaStream.  # noqa: E501

        The extended video sub\\-type description.  # noqa: E501

        :return: The extended_video_sub_type_description of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._extended_video_sub_type_description

    @extended_video_sub_type_description.setter
    def extended_video_sub_type_description(self, extended_video_sub_type_description):
        """Sets the extended_video_sub_type_description of this MediaStream.

        The extended video sub\\-type description.  # noqa: E501

        :param extended_video_sub_type_description: The extended_video_sub_type_description of this MediaStream.  # noqa: E501
        :type: str
        """

        self._extended_video_sub_type_description = extended_video_sub_type_description

    @property
    def item_id(self):
        """Gets the item_id of this MediaStream.  # noqa: E501

        Used only by our Windows app. Not used by Emby Server.  # noqa: E501

        :return: The item_id of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this MediaStream.

        Used only by our Windows app. Not used by Emby Server.  # noqa: E501

        :param item_id: The item_id of this MediaStream.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def server_id(self):
        """Gets the server_id of this MediaStream.  # noqa: E501

        Used only by our Windows app. Not used by Emby Server.  # noqa: E501

        :return: The server_id of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this MediaStream.

        Used only by our Windows app. Not used by Emby Server.  # noqa: E501

        :param server_id: The server_id of this MediaStream.  # noqa: E501
        :type: str
        """

        self._server_id = server_id

    @property
    def attachment_size(self):
        """Gets the attachment_size of this MediaStream.  # noqa: E501

        The size of the attachment.  # noqa: E501

        :return: The attachment_size of this MediaStream.  # noqa: E501
        :rtype: int
        """
        return self._attachment_size

    @attachment_size.setter
    def attachment_size(self, attachment_size):
        """Sets the attachment_size of this MediaStream.

        The size of the attachment.  # noqa: E501

        :param attachment_size: The attachment_size of this MediaStream.  # noqa: E501
        :type: int
        """

        self._attachment_size = attachment_size

    @property
    def mime_type(self):
        """Gets the mime_type of this MediaStream.  # noqa: E501

        The type of the MIME.  # noqa: E501

        :return: The mime_type of this MediaStream.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this MediaStream.

        The type of the MIME.  # noqa: E501

        :param mime_type: The mime_type of this MediaStream.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def subtitle_location_type(self):
        """Gets the subtitle_location_type of this MediaStream.  # noqa: E501


        :return: The subtitle_location_type of this MediaStream.  # noqa: E501
        :rtype: SubtitleLocationType
        """
        return self._subtitle_location_type

    @subtitle_location_type.setter
    def subtitle_location_type(self, subtitle_location_type):
        """Sets the subtitle_location_type of this MediaStream.


        :param subtitle_location_type: The subtitle_location_type of this MediaStream.  # noqa: E501
        :type: SubtitleLocationType
        """

        self._subtitle_location_type = subtitle_location_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MediaStream, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ExternalIdInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'key': 'str',
        'website': 'str',
        'url_format_string': 'str',
        'is_supported_as_identifier': 'bool'
    }

    attribute_map = {
        'name': 'Name',
        'key': 'Key',
        'website': 'Website',
        'url_format_string': 'UrlFormatString',
        'is_supported_as_identifier': 'IsSupportedAsIdentifier'
    }

    def __init__(self, name=None, key=None, website=None, url_format_string=None, is_supported_as_identifier=None):  # noqa: E501
        """ExternalIdInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._key = None
        self._website = None
        self._url_format_string = None
        self._is_supported_as_identifier = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if key is not None:
            self.key = key
        if website is not None:
            self.website = website
        if url_format_string is not None:
            self.url_format_string = url_format_string
        if is_supported_as_identifier is not None:
            self.is_supported_as_identifier = is_supported_as_identifier

    @property
    def name(self):
        """Gets the name of this ExternalIdInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this ExternalIdInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ExternalIdInfo.

        The name.  # noqa: E501

        :param name: The name of this ExternalIdInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def key(self):
        """Gets the key of this ExternalIdInfo.  # noqa: E501

        The key.  # noqa: E501

        :return: The key of this ExternalIdInfo.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ExternalIdInfo.

        The key.  # noqa: E501

        :param key: The key of this ExternalIdInfo.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def website(self):
        """Gets the website of this ExternalIdInfo.  # noqa: E501


        :return: The website of this ExternalIdInfo.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website):
        """Sets the website of this ExternalIdInfo.


        :param website: The website of this ExternalIdInfo.  # noqa: E501
        :type: str
        """

        self._website = website

    @property
    def url_format_string(self):
        """Gets the url_format_string of this ExternalIdInfo.  # noqa: E501

        The URL format string.  # noqa: E501

        :return: The url_format_string of this ExternalIdInfo.  # noqa: E501
        :rtype: str
        """
        return self._url_format_string

    @url_format_string.setter
    def url_format_string(self, url_format_string):
        """Sets the url_format_string of this ExternalIdInfo.

        The URL format string.  # noqa: E501

        :param url_format_string: The url_format_string of this ExternalIdInfo.  # noqa: E501
        :type: str
        """

        self._url_format_string = url_format_string

    @property
    def is_supported_as_identifier(self):
        """Gets the is_supported_as_identifier of this ExternalIdInfo.  # noqa: E501


        :return: The is_supported_as_identifier of this ExternalIdInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_supported_as_identifier

    @is_supported_as_identifier.setter
    def is_supported_as_identifier(self, is_supported_as_identifier):
        """Sets the is_supported_as_identifier of this ExternalIdInfo.


        :param is_supported_as_identifier: The is_supported_as_identifier of this ExternalIdInfo.  # noqa: E501
        :type: bool
        """

        self._is_supported_as_identifier = is_supported_as_identifier

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExternalIdInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExternalIdInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class DisplayPreferences(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'sort_by': 'str',
        'custom_prefs': 'dict(str, str)',
        'sort_order': 'SortOrder',
        'client': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'sort_by': 'SortBy',
        'custom_prefs': 'CustomPrefs',
        'sort_order': 'SortOrder',
        'client': 'Client'
    }

    def __init__(self, id=None, sort_by=None, custom_prefs=None, sort_order=None, client=None):  # noqa: E501
        """DisplayPreferences - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._sort_by = None
        self._custom_prefs = None
        self._sort_order = None
        self._client = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if sort_by is not None:
            self.sort_by = sort_by
        if custom_prefs is not None:
            self.custom_prefs = custom_prefs
        if sort_order is not None:
            self.sort_order = sort_order
        if client is not None:
            self.client = client

    @property
    def id(self):
        """Gets the id of this DisplayPreferences.  # noqa: E501


        :return: The id of this DisplayPreferences.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DisplayPreferences.


        :param id: The id of this DisplayPreferences.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def sort_by(self):
        """Gets the sort_by of this DisplayPreferences.  # noqa: E501


        :return: The sort_by of this DisplayPreferences.  # noqa: E501
        :rtype: str
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """Sets the sort_by of this DisplayPreferences.


        :param sort_by: The sort_by of this DisplayPreferences.  # noqa: E501
        :type: str
        """

        self._sort_by = sort_by

    @property
    def custom_prefs(self):
        """Gets the custom_prefs of this DisplayPreferences.  # noqa: E501


        :return: The custom_prefs of this DisplayPreferences.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._custom_prefs

    @custom_prefs.setter
    def custom_prefs(self, custom_prefs):
        """Sets the custom_prefs of this DisplayPreferences.


        :param custom_prefs: The custom_prefs of this DisplayPreferences.  # noqa: E501
        :type: dict(str, str)
        """

        self._custom_prefs = custom_prefs

    @property
    def sort_order(self):
        """Gets the sort_order of this DisplayPreferences.  # noqa: E501


        :return: The sort_order of this DisplayPreferences.  # noqa: E501
        :rtype: SortOrder
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this DisplayPreferences.


        :param sort_order: The sort_order of this DisplayPreferences.  # noqa: E501
        :type: SortOrder
        """

        self._sort_order = sort_order

    @property
    def client(self):
        """Gets the client of this DisplayPreferences.  # noqa: E501


        :return: The client of this DisplayPreferences.  # noqa: E501
        :rtype: str
        """
        return self._client

    @client.setter
    def client(self, client):
        """Sets the client of this DisplayPreferences.


        :param client: The client of this DisplayPreferences.  # noqa: E501
        :type: str
        """

        self._client = client

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DisplayPreferences, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DisplayPreferences):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PlayerStateInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'position_ticks': 'int',
        'can_seek': 'bool',
        'is_paused': 'bool',
        'is_muted': 'bool',
        'volume_level': 'int',
        'audio_stream_index': 'int',
        'subtitle_stream_index': 'int',
        'media_source_id': 'str',
        'play_method': 'PlayMethod',
        'repeat_mode': 'RepeatMode',
        'subtitle_offset': 'int',
        'shuffle': 'bool',
        'playback_rate': 'float'
    }

    attribute_map = {
        'position_ticks': 'PositionTicks',
        'can_seek': 'CanSeek',
        'is_paused': 'IsPaused',
        'is_muted': 'IsMuted',
        'volume_level': 'VolumeLevel',
        'audio_stream_index': 'AudioStreamIndex',
        'subtitle_stream_index': 'SubtitleStreamIndex',
        'media_source_id': 'MediaSourceId',
        'play_method': 'PlayMethod',
        'repeat_mode': 'RepeatMode',
        'subtitle_offset': 'SubtitleOffset',
        'shuffle': 'Shuffle',
        'playback_rate': 'PlaybackRate'
    }

    def __init__(self, position_ticks=None, can_seek=None, is_paused=None, is_muted=None, volume_level=None, audio_stream_index=None, subtitle_stream_index=None, media_source_id=None, play_method=None, repeat_mode=None, subtitle_offset=None, shuffle=None, playback_rate=None):  # noqa: E501
        """PlayerStateInfo - a model defined in Swagger"""  # noqa: E501
        self._position_ticks = None
        self._can_seek = None
        self._is_paused = None
        self._is_muted = None
        self._volume_level = None
        self._audio_stream_index = None
        self._subtitle_stream_index = None
        self._media_source_id = None
        self._play_method = None
        self._repeat_mode = None
        self._subtitle_offset = None
        self._shuffle = None
        self._playback_rate = None
        self.discriminator = None
        if position_ticks is not None:
            self.position_ticks = position_ticks
        if can_seek is not None:
            self.can_seek = can_seek
        if is_paused is not None:
            self.is_paused = is_paused
        if is_muted is not None:
            self.is_muted = is_muted
        if volume_level is not None:
            self.volume_level = volume_level
        if audio_stream_index is not None:
            self.audio_stream_index = audio_stream_index
        if subtitle_stream_index is not None:
            self.subtitle_stream_index = subtitle_stream_index
        if media_source_id is not None:
            self.media_source_id = media_source_id
        if play_method is not None:
            self.play_method = play_method
        if repeat_mode is not None:
            self.repeat_mode = repeat_mode
        if subtitle_offset is not None:
            self.subtitle_offset = subtitle_offset
        if shuffle is not None:
            self.shuffle = shuffle
        if playback_rate is not None:
            self.playback_rate = playback_rate

    @property
    def position_ticks(self):
        """Gets the position_ticks of this PlayerStateInfo.  # noqa: E501

        The now playing position ticks.  # noqa: E501

        :return: The position_ticks of this PlayerStateInfo.  # noqa: E501
        :rtype: int
        """
        return self._position_ticks

    @position_ticks.setter
    def position_ticks(self, position_ticks):
        """Sets the position_ticks of this PlayerStateInfo.

        The now playing position ticks.  # noqa: E501

        :param position_ticks: The position_ticks of this PlayerStateInfo.  # noqa: E501
        :type: int
        """

        self._position_ticks = position_ticks

    @property
    def can_seek(self):
        """Gets the can_seek of this PlayerStateInfo.  # noqa: E501

        A value indicating whether this instance can seek.  # noqa: E501

        :return: The can_seek of this PlayerStateInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_seek

    @can_seek.setter
    def can_seek(self, can_seek):
        """Sets the can_seek of this PlayerStateInfo.

        A value indicating whether this instance can seek.  # noqa: E501

        :param can_seek: The can_seek of this PlayerStateInfo.  # noqa: E501
        :type: bool
        """

        self._can_seek = can_seek

    @property
    def is_paused(self):
        """Gets the is_paused of this PlayerStateInfo.  # noqa: E501

        A value indicating whether this instance is paused.  # noqa: E501

        :return: The is_paused of this PlayerStateInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this PlayerStateInfo.

        A value indicating whether this instance is paused.  # noqa: E501

        :param is_paused: The is_paused of this PlayerStateInfo.  # noqa: E501
        :type: bool
        """

        self._is_paused = is_paused

    @property
    def is_muted(self):
        """Gets the is_muted of this PlayerStateInfo.  # noqa: E501

        A value indicating whether this instance is muted.  # noqa: E501

        :return: The is_muted of this PlayerStateInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_muted

    @is_muted.setter
    def is_muted(self, is_muted):
        """Sets the is_muted of this PlayerStateInfo.

        A value indicating whether this instance is muted.  # noqa: E501

        :param is_muted: The is_muted of this PlayerStateInfo.  # noqa: E501
        :type: bool
        """

        self._is_muted = is_muted

    @property
    def volume_level(self):
        """Gets the volume_level of this PlayerStateInfo.  # noqa: E501

        The volume level.  # noqa: E501

        :return: The volume_level of this PlayerStateInfo.  # noqa: E501
        :rtype: int
        """
        return self._volume_level

    @volume_level.setter
    def volume_level(self, volume_level):
        """Sets the volume_level of this PlayerStateInfo.

        The volume level.  # noqa: E501

        :param volume_level: The volume_level of this PlayerStateInfo.  # noqa: E501
        :type: int
        """

        self._volume_level = volume_level

    @property
    def audio_stream_index(self):
        """Gets the audio_stream_index of this PlayerStateInfo.  # noqa: E501

        The index of the now playing audio stream.  # noqa: E501

        :return: The audio_stream_index of this PlayerStateInfo.  # noqa: E501
        :rtype: int
        """
        return self._audio_stream_index

    @audio_stream_index.setter
    def audio_stream_index(self, audio_stream_index):
        """Sets the audio_stream_index of this PlayerStateInfo.

        The index of the now playing audio stream.  # noqa: E501

        :param audio_stream_index: The audio_stream_index of this PlayerStateInfo.  # noqa: E501
        :type: int
        """

        self._audio_stream_index = audio_stream_index

    @property
    def subtitle_stream_index(self):
        """Gets the subtitle_stream_index of this PlayerStateInfo.  # noqa: E501

        The index of the now playing subtitle stream.  # noqa: E501

        :return: The subtitle_stream_index of this PlayerStateInfo.  # noqa: E501
        :rtype: int
        """
        return self._subtitle_stream_index

    @subtitle_stream_index.setter
    def subtitle_stream_index(self, subtitle_stream_index):
        """Sets the subtitle_stream_index of this PlayerStateInfo.

        The index of the now playing subtitle stream.  # noqa: E501

        :param subtitle_stream_index: The subtitle_stream_index of this PlayerStateInfo.  # noqa: E501
        :type: int
        """

        self._subtitle_stream_index = subtitle_stream_index

    @property
    def media_source_id(self):
        """Gets the media_source_id of this PlayerStateInfo.  # noqa: E501

        The now playing media version identifier.  # noqa: E501

        :return: The media_source_id of this PlayerStateInfo.  # noqa: E501
        :rtype: str
        """
        return self._media_source_id

    @media_source_id.setter
    def media_source_id(self, media_source_id):
        """Sets the media_source_id of this PlayerStateInfo.

        The now playing media version identifier.  # noqa: E501

        :param media_source_id: The media_source_id of this PlayerStateInfo.  # noqa: E501
        :type: str
        """

        self._media_source_id = media_source_id

    @property
    def play_method(self):
        """Gets the play_method of this PlayerStateInfo.  # noqa: E501


        :return: The play_method of this PlayerStateInfo.  # noqa: E501
        :rtype: PlayMethod
        """
        return self._play_method

    @play_method.setter
    def play_method(self, play_method):
        """Sets the play_method of this PlayerStateInfo.


        :param play_method: The play_method of this PlayerStateInfo.  # noqa: E501
        :type: PlayMethod
        """

        self._play_method = play_method

    @property
    def repeat_mode(self):
        """Gets the repeat_mode of this PlayerStateInfo.  # noqa: E501


        :return: The repeat_mode of this PlayerStateInfo.  # noqa: E501
        :rtype: RepeatMode
        """
        return self._repeat_mode

    @repeat_mode.setter
    def repeat_mode(self, repeat_mode):
        """Sets the repeat_mode of this PlayerStateInfo.


        :param repeat_mode: The repeat_mode of this PlayerStateInfo.  # noqa: E501
        :type: RepeatMode
        """

        self._repeat_mode = repeat_mode

    @property
    def subtitle_offset(self):
        """Gets the subtitle_offset of this PlayerStateInfo.  # noqa: E501


        :return: The subtitle_offset of this PlayerStateInfo.  # noqa: E501
        :rtype: int
        """
        return self._subtitle_offset

    @subtitle_offset.setter
    def subtitle_offset(self, subtitle_offset):
        """Sets the subtitle_offset of this PlayerStateInfo.


        :param subtitle_offset: The subtitle_offset of this PlayerStateInfo.  # noqa: E501
        :type: int
        """

        self._subtitle_offset = subtitle_offset

    @property
    def shuffle(self):
        """Gets the shuffle of this PlayerStateInfo.  # noqa: E501


        :return: The shuffle of this PlayerStateInfo.  # noqa: E501
        :rtype: bool
        """
        return self._shuffle

    @shuffle.setter
    def shuffle(self, shuffle):
        """Sets the shuffle of this PlayerStateInfo.


        :param shuffle: The shuffle of this PlayerStateInfo.  # noqa: E501
        :type: bool
        """

        self._shuffle = shuffle

    @property
    def playback_rate(self):
        """Gets the playback_rate of this PlayerStateInfo.  # noqa: E501


        :return: The playback_rate of this PlayerStateInfo.  # noqa: E501
        :rtype: float
        """
        return self._playback_rate

    @playback_rate.setter
    def playback_rate(self, playback_rate):
        """Sets the playback_rate of this PlayerStateInfo.


        :param playback_rate: The playback_rate of this PlayerStateInfo.  # noqa: E501
        :type: float
        """

        self._playback_rate = playback_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayerStateInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayerStateInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class GenericEditIEditObjectContainer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'object': 'object',
        'default_object': 'object',
        'type_name': 'str'
    }

    attribute_map = {
        'object': 'Object',
        'default_object': 'DefaultObject',
        'type_name': 'TypeName'
    }

    def __init__(self, object=None, default_object=None, type_name=None):  # noqa: E501
        """GenericEditIEditObjectContainer - a model defined in Swagger"""  # noqa: E501
        self._object = None
        self._default_object = None
        self._type_name = None
        self.discriminator = None
        if object is not None:
            self.object = object
        if default_object is not None:
            self.default_object = default_object
        if type_name is not None:
            self.type_name = type_name

    @property
    def object(self):
        """Gets the object of this GenericEditIEditObjectContainer.  # noqa: E501


        :return: The object of this GenericEditIEditObjectContainer.  # noqa: E501
        :rtype: object
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this GenericEditIEditObjectContainer.


        :param object: The object of this GenericEditIEditObjectContainer.  # noqa: E501
        :type: object
        """

        self._object = object

    @property
    def default_object(self):
        """Gets the default_object of this GenericEditIEditObjectContainer.  # noqa: E501


        :return: The default_object of this GenericEditIEditObjectContainer.  # noqa: E501
        :rtype: object
        """
        return self._default_object

    @default_object.setter
    def default_object(self, default_object):
        """Sets the default_object of this GenericEditIEditObjectContainer.


        :param default_object: The default_object of this GenericEditIEditObjectContainer.  # noqa: E501
        :type: object
        """

        self._default_object = default_object

    @property
    def type_name(self):
        """Gets the type_name of this GenericEditIEditObjectContainer.  # noqa: E501


        :return: The type_name of this GenericEditIEditObjectContainer.  # noqa: E501
        :rtype: str
        """
        return self._type_name

    @type_name.setter
    def type_name(self, type_name):
        """Sets the type_name of this GenericEditIEditObjectContainer.


        :param type_name: The type_name of this GenericEditIEditObjectContainer.  # noqa: E501
        :type: str
        """

        self._type_name = type_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenericEditIEditObjectContainer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenericEditIEditObjectContainer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class InstallationInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'assembly_guid': 'str',
        'version': 'str',
        'update_class': 'PackageVersionClass',
        'percent_complete': 'float'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'assembly_guid': 'AssemblyGuid',
        'version': 'Version',
        'update_class': 'UpdateClass',
        'percent_complete': 'PercentComplete'
    }

    def __init__(self, id=None, name=None, assembly_guid=None, version=None, update_class=None, percent_complete=None):  # noqa: E501
        """InstallationInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._assembly_guid = None
        self._version = None
        self._update_class = None
        self._percent_complete = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if assembly_guid is not None:
            self.assembly_guid = assembly_guid
        if version is not None:
            self.version = version
        if update_class is not None:
            self.update_class = update_class
        if percent_complete is not None:
            self.percent_complete = percent_complete

    @property
    def id(self):
        """Gets the id of this InstallationInfo.  # noqa: E501

        The id.  # noqa: E501

        :return: The id of this InstallationInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InstallationInfo.

        The id.  # noqa: E501

        :param id: The id of this InstallationInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this InstallationInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this InstallationInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InstallationInfo.

        The name.  # noqa: E501

        :param name: The name of this InstallationInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def assembly_guid(self):
        """Gets the assembly_guid of this InstallationInfo.  # noqa: E501

        The assembly guid.  # noqa: E501

        :return: The assembly_guid of this InstallationInfo.  # noqa: E501
        :rtype: str
        """
        return self._assembly_guid

    @assembly_guid.setter
    def assembly_guid(self, assembly_guid):
        """Sets the assembly_guid of this InstallationInfo.

        The assembly guid.  # noqa: E501

        :param assembly_guid: The assembly_guid of this InstallationInfo.  # noqa: E501
        :type: str
        """

        self._assembly_guid = assembly_guid

    @property
    def version(self):
        """Gets the version of this InstallationInfo.  # noqa: E501

        The version.  # noqa: E501

        :return: The version of this InstallationInfo.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InstallationInfo.

        The version.  # noqa: E501

        :param version: The version of this InstallationInfo.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def update_class(self):
        """Gets the update_class of this InstallationInfo.  # noqa: E501


        :return: The update_class of this InstallationInfo.  # noqa: E501
        :rtype: PackageVersionClass
        """
        return self._update_class

    @update_class.setter
    def update_class(self, update_class):
        """Sets the update_class of this InstallationInfo.


        :param update_class: The update_class of this InstallationInfo.  # noqa: E501
        :type: PackageVersionClass
        """

        self._update_class = update_class

    @property
    def percent_complete(self):
        """Gets the percent_complete of this InstallationInfo.  # noqa: E501

        The percent complete.  # noqa: E501

        :return: The percent_complete of this InstallationInfo.  # noqa: E501
        :rtype: float
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """Sets the percent_complete of this InstallationInfo.

        The percent complete.  # noqa: E501

        :param percent_complete: The percent_complete of this InstallationInfo.  # noqa: E501
        :type: float
        """

        self._percent_complete = percent_complete

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstallationInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstallationInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class SystemServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_system_endpoint(self, **kwargs):  # noqa: E501
        """Gets information about the request endpoint  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_endpoint(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: NetEndPointInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_endpoint_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_endpoint_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_endpoint_with_http_info(self, **kwargs):  # noqa: E501
        """Gets information about the request endpoint  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_endpoint_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: NetEndPointInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_endpoint" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Endpoint', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NetEndPointInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_info(self, **kwargs):  # noqa: E501
        """Gets information about the server  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SystemInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_info_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_info_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_info_with_http_info(self, **kwargs):  # noqa: E501
        """Gets information about the server  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: SystemInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_info" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SystemInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_info_public(self, **kwargs):  # noqa: E501
        """Gets public information about the server  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_info_public(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: PublicSystemInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_info_public_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_info_public_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_info_public_with_http_info(self, **kwargs):  # noqa: E501
        """Gets public information about the server  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_info_public_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: PublicSystemInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_info_public" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Info/Public', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PublicSystemInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_logs_by_name(self, name, **kwargs):  # noqa: E501
        """Gets a log file  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_logs_by_name(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The log file name. (required)
        :param bool sanitize: Return sanitized log
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_logs_by_name_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_system_logs_by_name_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_system_logs_by_name_with_http_info(self, name, **kwargs):  # noqa: E501
        """Gets a log file  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_logs_by_name_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The log file name. (required)
        :param bool sanitize: Return sanitized log
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'sanitize']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_logs_by_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_system_logs_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['Name'] = params['name']  # noqa: E501

        query_params = []
        if 'sanitize' in params:
            query_params.append(('Sanitize', params['sanitize']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Logs/{Name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_logs_by_name_lines(self, name, **kwargs):  # noqa: E501
        """Gets a log file  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_logs_by_name_lines(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The log file name. (required)
        :return: QueryResultString
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_logs_by_name_lines_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_system_logs_by_name_lines_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_system_logs_by_name_lines_with_http_info(self, name, **kwargs):  # noqa: E501
        """Gets a log file  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_logs_by_name_lines_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The log file name. (required)
        :return: QueryResultString
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_logs_by_name_lines" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_system_logs_by_name_lines`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['Name'] = params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Logs/{Name}/Lines', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultString',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_logs_query(self, **kwargs):  # noqa: E501
        """Gets a list of available server log files  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_logs_query(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :return: QueryResultLogFile
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_logs_query_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_logs_query_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_logs_query_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a list of available server log files  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_logs_query_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :return: QueryResultLogFile
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['start_index', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_logs_query" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'start_index' in params:
            query_params.append(('StartIndex', params['start_index']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Logs/Query', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultLogFile',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_ping(self, **kwargs):  # noqa: E501
        """get_system_ping  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_ping(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_ping_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_ping_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_ping_with_http_info(self, **kwargs):  # noqa: E501
        """get_system_ping  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_ping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_ping" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Ping', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_releasenotes(self, **kwargs):  # noqa: E501
        """Gets release notes  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_releasenotes(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: PackageVersionInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_releasenotes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_releasenotes_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_releasenotes_with_http_info(self, **kwargs):  # noqa: E501
        """Gets release notes  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_releasenotes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: PackageVersionInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_releasenotes" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/ReleaseNotes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PackageVersionInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_releasenotes_versions(self, **kwargs):  # noqa: E501
        """Gets release notes  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_releasenotes_versions(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[PackageVersionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_releasenotes_versions_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_releasenotes_versions_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_releasenotes_versions_with_http_info(self, **kwargs):  # noqa: E501
        """Gets release notes  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_releasenotes_versions_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[PackageVersionInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_releasenotes_versions" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/ReleaseNotes/Versions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PackageVersionInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_wakeonlaninfo(self, **kwargs):  # noqa: E501
        """Gets wake on lan information  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_wakeonlaninfo(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[WakeOnLanInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_wakeonlaninfo_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_wakeonlaninfo_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_wakeonlaninfo_with_http_info(self, **kwargs):  # noqa: E501
        """Gets wake on lan information  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_wakeonlaninfo_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[WakeOnLanInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_wakeonlaninfo" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/WakeOnLanInfo', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[WakeOnLanInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_system_ping(self, **kwargs):  # noqa: E501
        """post_system_ping  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_system_ping(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_system_ping_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_system_ping_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_system_ping_with_http_info(self, **kwargs):  # noqa: E501
        """post_system_ping  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_system_ping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_system_ping" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Ping', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_system_restart(self, **kwargs):  # noqa: E501
        """Restarts the application, if needed  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_system_restart(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_system_restart_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_system_restart_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_system_restart_with_http_info(self, **kwargs):  # noqa: E501
        """Restarts the application, if needed  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_system_restart_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_system_restart" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Restart', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_system_shutdown(self, **kwargs):  # noqa: E501
        """Shuts down the application  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_system_shutdown(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_system_shutdown_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.post_system_shutdown_with_http_info(**kwargs)  # noqa: E501
            return data

    def post_system_shutdown_with_http_info(self, **kwargs):  # noqa: E501
        """Shuts down the application  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_system_shutdown_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_system_shutdown" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/System/Shutdown', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class SyncedItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'server_id': 'str',
        'sync_job_id': 'int',
        'sync_job_name': 'str',
        'sync_job_date_created': 'datetime',
        'sync_job_item_id': 'int',
        'original_file_name': 'str',
        'item': 'BaseItemDto',
        'user_id': 'str',
        'additional_files': 'list[ItemFileInfo]'
    }

    attribute_map = {
        'server_id': 'ServerId',
        'sync_job_id': 'SyncJobId',
        'sync_job_name': 'SyncJobName',
        'sync_job_date_created': 'SyncJobDateCreated',
        'sync_job_item_id': 'SyncJobItemId',
        'original_file_name': 'OriginalFileName',
        'item': 'Item',
        'user_id': 'UserId',
        'additional_files': 'AdditionalFiles'
    }

    def __init__(self, server_id=None, sync_job_id=None, sync_job_name=None, sync_job_date_created=None, sync_job_item_id=None, original_file_name=None, item=None, user_id=None, additional_files=None):  # noqa: E501
        """SyncedItem - a model defined in Swagger"""  # noqa: E501
        self._server_id = None
        self._sync_job_id = None
        self._sync_job_name = None
        self._sync_job_date_created = None
        self._sync_job_item_id = None
        self._original_file_name = None
        self._item = None
        self._user_id = None
        self._additional_files = None
        self.discriminator = None
        if server_id is not None:
            self.server_id = server_id
        if sync_job_id is not None:
            self.sync_job_id = sync_job_id
        if sync_job_name is not None:
            self.sync_job_name = sync_job_name
        if sync_job_date_created is not None:
            self.sync_job_date_created = sync_job_date_created
        if sync_job_item_id is not None:
            self.sync_job_item_id = sync_job_item_id
        if original_file_name is not None:
            self.original_file_name = original_file_name
        if item is not None:
            self.item = item
        if user_id is not None:
            self.user_id = user_id
        if additional_files is not None:
            self.additional_files = additional_files

    @property
    def server_id(self):
        """Gets the server_id of this SyncedItem.  # noqa: E501


        :return: The server_id of this SyncedItem.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this SyncedItem.


        :param server_id: The server_id of this SyncedItem.  # noqa: E501
        :type: str
        """

        self._server_id = server_id

    @property
    def sync_job_id(self):
        """Gets the sync_job_id of this SyncedItem.  # noqa: E501


        :return: The sync_job_id of this SyncedItem.  # noqa: E501
        :rtype: int
        """
        return self._sync_job_id

    @sync_job_id.setter
    def sync_job_id(self, sync_job_id):
        """Sets the sync_job_id of this SyncedItem.


        :param sync_job_id: The sync_job_id of this SyncedItem.  # noqa: E501
        :type: int
        """

        self._sync_job_id = sync_job_id

    @property
    def sync_job_name(self):
        """Gets the sync_job_name of this SyncedItem.  # noqa: E501


        :return: The sync_job_name of this SyncedItem.  # noqa: E501
        :rtype: str
        """
        return self._sync_job_name

    @sync_job_name.setter
    def sync_job_name(self, sync_job_name):
        """Sets the sync_job_name of this SyncedItem.


        :param sync_job_name: The sync_job_name of this SyncedItem.  # noqa: E501
        :type: str
        """

        self._sync_job_name = sync_job_name

    @property
    def sync_job_date_created(self):
        """Gets the sync_job_date_created of this SyncedItem.  # noqa: E501


        :return: The sync_job_date_created of this SyncedItem.  # noqa: E501
        :rtype: datetime
        """
        return self._sync_job_date_created

    @sync_job_date_created.setter
    def sync_job_date_created(self, sync_job_date_created):
        """Sets the sync_job_date_created of this SyncedItem.


        :param sync_job_date_created: The sync_job_date_created of this SyncedItem.  # noqa: E501
        :type: datetime
        """

        self._sync_job_date_created = sync_job_date_created

    @property
    def sync_job_item_id(self):
        """Gets the sync_job_item_id of this SyncedItem.  # noqa: E501


        :return: The sync_job_item_id of this SyncedItem.  # noqa: E501
        :rtype: int
        """
        return self._sync_job_item_id

    @sync_job_item_id.setter
    def sync_job_item_id(self, sync_job_item_id):
        """Sets the sync_job_item_id of this SyncedItem.


        :param sync_job_item_id: The sync_job_item_id of this SyncedItem.  # noqa: E501
        :type: int
        """

        self._sync_job_item_id = sync_job_item_id

    @property
    def original_file_name(self):
        """Gets the original_file_name of this SyncedItem.  # noqa: E501


        :return: The original_file_name of this SyncedItem.  # noqa: E501
        :rtype: str
        """
        return self._original_file_name

    @original_file_name.setter
    def original_file_name(self, original_file_name):
        """Sets the original_file_name of this SyncedItem.


        :param original_file_name: The original_file_name of this SyncedItem.  # noqa: E501
        :type: str
        """

        self._original_file_name = original_file_name

    @property
    def item(self):
        """Gets the item of this SyncedItem.  # noqa: E501


        :return: The item of this SyncedItem.  # noqa: E501
        :rtype: BaseItemDto
        """
        return self._item

    @item.setter
    def item(self, item):
        """Sets the item of this SyncedItem.


        :param item: The item of this SyncedItem.  # noqa: E501
        :type: BaseItemDto
        """

        self._item = item

    @property
    def user_id(self):
        """Gets the user_id of this SyncedItem.  # noqa: E501


        :return: The user_id of this SyncedItem.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this SyncedItem.


        :param user_id: The user_id of this SyncedItem.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def additional_files(self):
        """Gets the additional_files of this SyncedItem.  # noqa: E501


        :return: The additional_files of this SyncedItem.  # noqa: E501
        :rtype: list[ItemFileInfo]
        """
        return self._additional_files

    @additional_files.setter
    def additional_files(self, additional_files):
        """Sets the additional_files of this SyncedItem.


        :param additional_files: The additional_files of this SyncedItem.  # noqa: E501
        :type: list[ItemFileInfo]
        """

        self._additional_files = additional_files

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyncedItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncedItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class TranscodingVpStepInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'step_type': 'TranscodingVpStepTypes',
        'step_type_name': 'str',
        'hardware_context_name': 'str',
        'is_hardware_context': 'bool',
        'name': 'str',
        'short': 'str',
        'ffmpeg_name': 'str',
        'ffmpeg_description': 'str',
        'ffmpeg_options': 'str',
        'param': 'str',
        'param_short': 'str'
    }

    attribute_map = {
        'step_type': 'StepType',
        'step_type_name': 'StepTypeName',
        'hardware_context_name': 'HardwareContextName',
        'is_hardware_context': 'IsHardwareContext',
        'name': 'Name',
        'short': 'Short',
        'ffmpeg_name': 'FfmpegName',
        'ffmpeg_description': 'FfmpegDescription',
        'ffmpeg_options': 'FfmpegOptions',
        'param': 'Param',
        'param_short': 'ParamShort'
    }

    def __init__(self, step_type=None, step_type_name=None, hardware_context_name=None, is_hardware_context=None, name=None, short=None, ffmpeg_name=None, ffmpeg_description=None, ffmpeg_options=None, param=None, param_short=None):  # noqa: E501
        """TranscodingVpStepInfo - a model defined in Swagger"""  # noqa: E501
        self._step_type = None
        self._step_type_name = None
        self._hardware_context_name = None
        self._is_hardware_context = None
        self._name = None
        self._short = None
        self._ffmpeg_name = None
        self._ffmpeg_description = None
        self._ffmpeg_options = None
        self._param = None
        self._param_short = None
        self.discriminator = None
        if step_type is not None:
            self.step_type = step_type
        if step_type_name is not None:
            self.step_type_name = step_type_name
        if hardware_context_name is not None:
            self.hardware_context_name = hardware_context_name
        if is_hardware_context is not None:
            self.is_hardware_context = is_hardware_context
        if name is not None:
            self.name = name
        if short is not None:
            self.short = short
        if ffmpeg_name is not None:
            self.ffmpeg_name = ffmpeg_name
        if ffmpeg_description is not None:
            self.ffmpeg_description = ffmpeg_description
        if ffmpeg_options is not None:
            self.ffmpeg_options = ffmpeg_options
        if param is not None:
            self.param = param
        if param_short is not None:
            self.param_short = param_short

    @property
    def step_type(self):
        """Gets the step_type of this TranscodingVpStepInfo.  # noqa: E501


        :return: The step_type of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: TranscodingVpStepTypes
        """
        return self._step_type

    @step_type.setter
    def step_type(self, step_type):
        """Sets the step_type of this TranscodingVpStepInfo.


        :param step_type: The step_type of this TranscodingVpStepInfo.  # noqa: E501
        :type: TranscodingVpStepTypes
        """

        self._step_type = step_type

    @property
    def step_type_name(self):
        """Gets the step_type_name of this TranscodingVpStepInfo.  # noqa: E501


        :return: The step_type_name of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._step_type_name

    @step_type_name.setter
    def step_type_name(self, step_type_name):
        """Sets the step_type_name of this TranscodingVpStepInfo.


        :param step_type_name: The step_type_name of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._step_type_name = step_type_name

    @property
    def hardware_context_name(self):
        """Gets the hardware_context_name of this TranscodingVpStepInfo.  # noqa: E501


        :return: The hardware_context_name of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._hardware_context_name

    @hardware_context_name.setter
    def hardware_context_name(self, hardware_context_name):
        """Sets the hardware_context_name of this TranscodingVpStepInfo.


        :param hardware_context_name: The hardware_context_name of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._hardware_context_name = hardware_context_name

    @property
    def is_hardware_context(self):
        """Gets the is_hardware_context of this TranscodingVpStepInfo.  # noqa: E501


        :return: The is_hardware_context of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_hardware_context

    @is_hardware_context.setter
    def is_hardware_context(self, is_hardware_context):
        """Sets the is_hardware_context of this TranscodingVpStepInfo.


        :param is_hardware_context: The is_hardware_context of this TranscodingVpStepInfo.  # noqa: E501
        :type: bool
        """

        self._is_hardware_context = is_hardware_context

    @property
    def name(self):
        """Gets the name of this TranscodingVpStepInfo.  # noqa: E501


        :return: The name of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TranscodingVpStepInfo.


        :param name: The name of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def short(self):
        """Gets the short of this TranscodingVpStepInfo.  # noqa: E501


        :return: The short of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._short

    @short.setter
    def short(self, short):
        """Sets the short of this TranscodingVpStepInfo.


        :param short: The short of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._short = short

    @property
    def ffmpeg_name(self):
        """Gets the ffmpeg_name of this TranscodingVpStepInfo.  # noqa: E501


        :return: The ffmpeg_name of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._ffmpeg_name

    @ffmpeg_name.setter
    def ffmpeg_name(self, ffmpeg_name):
        """Sets the ffmpeg_name of this TranscodingVpStepInfo.


        :param ffmpeg_name: The ffmpeg_name of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._ffmpeg_name = ffmpeg_name

    @property
    def ffmpeg_description(self):
        """Gets the ffmpeg_description of this TranscodingVpStepInfo.  # noqa: E501


        :return: The ffmpeg_description of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._ffmpeg_description

    @ffmpeg_description.setter
    def ffmpeg_description(self, ffmpeg_description):
        """Sets the ffmpeg_description of this TranscodingVpStepInfo.


        :param ffmpeg_description: The ffmpeg_description of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._ffmpeg_description = ffmpeg_description

    @property
    def ffmpeg_options(self):
        """Gets the ffmpeg_options of this TranscodingVpStepInfo.  # noqa: E501


        :return: The ffmpeg_options of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._ffmpeg_options

    @ffmpeg_options.setter
    def ffmpeg_options(self, ffmpeg_options):
        """Sets the ffmpeg_options of this TranscodingVpStepInfo.


        :param ffmpeg_options: The ffmpeg_options of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._ffmpeg_options = ffmpeg_options

    @property
    def param(self):
        """Gets the param of this TranscodingVpStepInfo.  # noqa: E501


        :return: The param of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._param

    @param.setter
    def param(self, param):
        """Sets the param of this TranscodingVpStepInfo.


        :param param: The param of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._param = param

    @property
    def param_short(self):
        """Gets the param_short of this TranscodingVpStepInfo.  # noqa: E501


        :return: The param_short of this TranscodingVpStepInfo.  # noqa: E501
        :rtype: str
        """
        return self._param_short

    @param_short.setter
    def param_short(self, param_short):
        """Sets the param_short of this TranscodingVpStepInfo.


        :param param_short: The param_short of this TranscodingVpStepInfo.  # noqa: E501
        :type: str
        """

        self._param_short = param_short

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TranscodingVpStepInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranscodingVpStepInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


VERSION = "4.9.0.29"
REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]


classifiers = [
    'Intended Audience :: Developers',  # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'Topic :: Multimedia :: Video',
    'Topic :: Multimedia',
    'Topic :: Internet :: WWW/HTTP',
    'Operating System :: OS Independent'
]

setuptools.setup(
    name="embyclient",
    packages=setuptools.find_packages(exclude=["tests"]),
    include_package_data=True,
    version=VERSION,
    install_requires=REQUIRES,
    description="A Python client for Emby Media Server's API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://emby.media",
    keywords=["Emby", "Rest", "API", "client", "media", "server", "JSON"],
    classifiers=classifiers,
)
